from distutils.core import setup
setup(
  name = 'G30S',
  packages = ['G30S'],
  version = '0.1',
  license='MIT',
  description = 'Simple text encoder using python',
  author = 'Billal X Code',
  author_email = 'billal.xcode@gmail.com',
  url = 'https://github.com/billalxcode/G30S',
  keywords = ['encoder', 'encrypt', 'crypto', 'decoder', 'encoding', 'hash', 'g30s', 'indonesian', 'python', 'base64'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
